#include "QC_XmlDoc.cpp"
#include "QC_XmlNode.cpp"
#include "QC_XmlReader.cpp"
#include "QC_XmlRpcClient.cpp"
#include "QC_SaxIterator.cpp"
#include "QC_FileSaxIterator.cpp"
#include "QC_InputStreamSaxIterator.cpp"
#include "ql_xml.cpp"
#include "qc_option.cpp"
#include "xml-module.cpp"
#include "QoreXmlReader.cpp"
#include "QoreXmlRpcReader.cpp"
#include "MakeXmlOpts.cpp"
#include "QC_AbstractXmlIoInputCallback.cpp"
